-----------
Description
-----------

This project provides interfaces that connect to Magento via its SOAP v1 XML-RPC interface.


-------------
Configuration
-------------

The following environment variables must be defined:

- `MAGENTO_USERNAME`
- `MAGENTO_PASSWORD`
- `MAGENTO_HOSTNAME`

You may optionally define:

- `MAGENTO_PORT`
